ReqMD Markdown
Structs
- Address
String - Address String AST
- Body
Data - Body Data
- Document
- Markdown Document AST
- Global
Http Defaults - Global HTTP Defaults
- Http
Data - HTTP Data
- Meta
Data - Meta Data AST
- Point
- Defines a position in the source code where data is located. This includes line number, column number, and byte offset.
- Position
- Source code position with start and end points.
Enums
- Error
- Reqmd Markdown Error
Functions
- parse_
markdown - Parse Markdown Document